@@ -75,8 +75,7 @@ class StructureReference(Field):
             else value
         )
         newval = self._newclass(**extracted_values)
-        super().__set__(instance,   newval)
-
+        super().__set__(instance, newval)
 
     def __serialize__(self, value):
         raise TypeError("{}: StructuredReference Cannot be pickled".format(self._name))
@@ -113,13 +112,13 @@ class Number(Field):
     """
 
     def __init__(
-            self,
-            *args,
-            multiplesOf=None,
-            minimum=None,
-            maximum=None,
-            exclusiveMaximum=None,
-            **kwargs
+        self,
+        *args,
+        multiplesOf=None,
+        minimum=None,
+        maximum=None,
+        exclusiveMaximum=None,
+        **kwargs
     ):
         self.multiplesOf = multiplesOf
         self.minimum = minimum
@@ -140,10 +139,10 @@ class Number(Field):
         if not is_number(value):
             raise TypeError("{}Expected a number".format(err_prefix()))
         if (
-                isinstance(self.multiplesOf, float)
-                and int(value / self.multiplesOf) != value / self.multiplesOf
-                or isinstance(self.multiplesOf, int)
-                and value % self.multiplesOf
+            isinstance(self.multiplesOf, float)
+            and int(value / self.multiplesOf) != value / self.multiplesOf
+            or isinstance(self.multiplesOf, int)
+            and value % self.multiplesOf
         ):
             raise ValueError(
                 "{}Expected a a multiple of {}".format(err_prefix(), self.multiplesOf)
@@ -369,45 +368,82 @@ class _ListStruct(list):
     def __setitem__(self, key, value):
         copied = super().copy()
         copied.__setitem__(key, value)
-        setattr(self._instance, getattr(self._field_definition, "_name", None),
-                _ListStruct(array=self._field_definition, struct_instance=self._instance, mylist=copied)
-                )
+        setattr(
+            self._instance,
+            getattr(self._field_definition, "_name", None),
+            _ListStruct(
+                array=self._field_definition,
+                struct_instance=self._instance,
+                mylist=copied,
+            ),
+        )
 
     def append(self, value):
         copied = super().copy()
         copied.append(value)
-        setattr(self._instance, getattr(self._field_definition, "_name", None),
-                _ListStruct(array=self._field_definition, struct_instance=self._instance, mylist=copied)
-                )
+        setattr(
+            self._instance,
+            getattr(self._field_definition, "_name", None),
+            _ListStruct(
+                array=self._field_definition,
+                struct_instance=self._instance,
+                mylist=copied,
+            ),
+        )
         super().append(value)
 
     def extend(self, value):
         copied = super().copy()
         copied.extend(value)
         if getattr(self, "_instance", None):
-            setattr(self._instance, getattr(self._field_definition, "_name", None),
-                    _ListStruct(array=self._field_definition, struct_instance=self._instance, mylist=copied))
+            setattr(
+                self._instance,
+                getattr(self._field_definition, "_name", None),
+                _ListStruct(
+                    array=self._field_definition,
+                    struct_instance=self._instance,
+                    mylist=copied,
+                ),
+            )
 
     def insert(self, index: int, value):
         copied = super().copy()
         copied.insert(index, value)
-        setattr(self._instance, getattr(self._field_definition, "_name", None),
-                _ListStruct(array=self._field_definition, struct_instance=self._instance, mylist=copied)
-                )
+        setattr(
+            self._instance,
+            getattr(self._field_definition, "_name", None),
+            _ListStruct(
+                array=self._field_definition,
+                struct_instance=self._instance,
+                mylist=copied,
+            ),
+        )
 
     def remove(self, ind):
         copied = super().copy()
         copied.remove(ind)
-        setattr(self._instance, getattr(self._field_definition, "_name", None),
-                _ListStruct(array=self._field_definition, struct_instance=self._instance, mylist=copied)
-                )
+        setattr(
+            self._instance,
+            getattr(self._field_definition, "_name", None),
+            _ListStruct(
+                array=self._field_definition,
+                struct_instance=self._instance,
+                mylist=copied,
+            ),
+        )
 
     def pop(self, index: int = -1):
         copied = super().copy()
         res = copied.pop(index)
-        setattr(self._instance, getattr(self._field_definition, "_name", None),
-                _ListStruct(array=self._field_definition, struct_instance=self._instance, mylist=copied)
-                )
+        setattr(
+            self._instance,
+            getattr(self._field_definition, "_name", None),
+            _ListStruct(
+                array=self._field_definition,
+                struct_instance=self._instance,
+                mylist=copied,
+            ),
+        )
         return res
 
     def __reduce__(self):
@@ -421,7 +457,10 @@ class _ListStruct(list):
         # state since deepcopy doesn't need it to create a copy.
         res = super().__reduce__()
         construction_func = res[0]
-        if construction_func.__module__ == 'copyreg' and construction_func.__name__ == '_reconstructor':
+        if (
+            construction_func.__module__ == "copyreg"
+            and construction_func.__name__ == "_reconstructor"
+        ):
             return res[0], res[1]
         return res
 
@@ -457,7 +496,9 @@ class _DictStruct(dict):
         copied = self.copy()
         copied.__setitem__(key, value)
         if getattr(self, "_instance", None):
-            setattr(self._instance, getattr(self._field_definition, "_name", None), copied)
+            setattr(
+                self._instance, getattr(self._field_definition, "_name", None), copied
+            )
         super().__setitem__(key, value)
 
     def __delitem__(self, key):
@@ -472,7 +513,11 @@ class _DictStruct(dict):
         return res
 
     def __getstate__(self):
-        return {"_instance": self._instance, "_map": self._field_definition, "mydict": self.copy()}
+        return {
+            "_instance": self._instance,
+            "_map": self._field_definition,
+            "mydict": self.copy(),
+        }
 
     def __setstate__(self, state):
         self._field_definition = state["_map"]
@@ -576,7 +621,7 @@ class Set(SizedCollection, TypedField, metaclass=_CollectionMeta):
         self.items = _map_to_field(items)
 
         if isinstance(self.items, TypedField) and not getattr(
-                getattr(self.items, "_ty"), "__hash__"
+            getattr(self.items, "_ty"), "__hash__"
         ):
             raise TypeError(
                 "Set element of type {} is not hashable".format(
@@ -630,7 +675,7 @@ class Map(SizedCollection, TypedField, metaclass=_CollectionMeta):
 
     def __init__(self, *args, items=None, **kwargs):
         if items is not None and (
-                not isinstance(items, (tuple, list)) or len(items) != 2
+            not isinstance(items, (tuple, list)) or len(items) != 2
         ):
             raise TypeError("items is expected to be a list/tuple of two fields")
         if items is None:
@@ -641,7 +686,7 @@ class Map(SizedCollection, TypedField, metaclass=_CollectionMeta):
                 self.items.append(_map_to_field(item))
             key_field = self.items[0]
             if isinstance(key_field, TypedField) and not getattr(
-                    getattr(key_field, "_ty"), "__hash__"
+                getattr(key_field, "_ty"), "__hash__"
             ):
                 raise TypeError(
                     "Key field of type {}, with underlying type of {} is not hashable".format(
@@ -711,7 +756,7 @@ class Array(SizedCollection, TypedField, metaclass=_CollectionMeta):
     _ty = list
 
     def __init__(
-            self, *args, items=None, uniqueItems=None, additionalItems=None, **kwargs
+        self, *args, items=None, uniqueItems=None, additionalItems=None, **kwargs
     ):
         """
         Constructor
@@ -751,7 +796,7 @@ class Array(SizedCollection, TypedField, metaclass=_CollectionMeta):
 
                 if not getattr(instance, "_skip_validation", False):
                     if len(self.items) > len(value) or (
-                            additional_properties_forbidden and len(self.items) > len(value)
+                        additional_properties_forbidden and len(self.items) > len(value)
                     ):
                         raise ValueError(
                             "{}: Got {}; Expected an array of length {}".format(
@@ -767,7 +812,7 @@ class Array(SizedCollection, TypedField, metaclass=_CollectionMeta):
                     setattr(item, "_name", self._name + "_{}".format(str(ind)))
                     item.__set__(temp_st, value[ind])
                     res.append(getattr(temp_st, getattr(item, "_name")))
-                res += value[len(self.items):]
+                res += value[len(self.items) :]
                 value = res
 
         super().__set__(instance, _ListStruct(self, instance, value))
@@ -874,7 +919,7 @@ class Tuple(TypedField, metaclass=_CollectionMeta):
             setattr(item, "_name", self._name + "_{}".format(str(ind)))
             item.__set__(temp_st, value[ind])
             res.append(getattr(temp_st, getattr(item, "_name")))
-            res += value[len(items):]
+            res += value[len(items) :]
         value = tuple(res)
 
         super().__set__(instance, value)
@@ -1222,12 +1267,9 @@ class SerializableField(ABC):
     can override the method:
       serialize(self, value),
       deserialize(self, value)
-    """
 
-    def __serialize__(self, value):
-        if getattr(self, '__getstate__', None):
-            return self.__getstate__()
-        return self.serialize(value)
+    These methods are not being used for pickling.
+    """
 
     def serialize(self, value):
         return value
