@@ -28,7 +28,8 @@ from typedpy.fields import (
     SerializableField,
     SizedCollection,
     wrap_val,
-    Function, _DictStruct,
+    Function,
+    _DictStruct,
 )
 
 
@@ -59,7 +60,7 @@ def deserialize_list_like(field, content_type, value, name):
             except (ValueError, TypeError) as e:
                 raise ValueError("{}_{}: {}".format(name, i, str(e)))
             values.append(res)
-        values += value[len(items):]
+        values += value[len(items) :]
     return content_type(values)
 
 
@@ -134,9 +135,9 @@ def deserialize_single_field(field, source_val, name, keep_undefined=True):
         field._validate(source_val)
         value = source_val
     elif (
-            isinstance(field, TypedField)
-            and getattr(field, "_ty", "") in {str, int, float}
-            and isinstance(source_val, getattr(field, "_ty", ""))
+        isinstance(field, TypedField)
+        and getattr(field, "_ty", "") in {str, int, float}
+        and isinstance(source_val, getattr(field, "_ty", ""))
     ):
         value = source_val
     elif isinstance(field, Array):
@@ -213,7 +214,7 @@ class FunctionCall(Structure):
 
 
 def deserialize_structure_internal(
-        cls, the_dict, name=None, *, mapper=None, keep_undefined=True
+    cls, the_dict, name=None, *, mapper=None, keep_undefined=True
 ):
     """
     Deserialize a dict to a Structure instance, Jackson style.
@@ -338,9 +339,9 @@ def get_processed_input(key, mapper, the_dict):
     return processed_input
 
 
-def serialize_val(field_definition, name, val):
+def serialize_val(field_definition, name, val, mapper=None):
     if isinstance(field_definition, SerializableField) and isinstance(
-            field_definition, Field
+        field_definition, Field
     ):
         return field_definition.serialize(val)
     if isinstance(val, (int, str, bool, float)) or val is None:
@@ -352,8 +353,8 @@ def serialize_val(field_definition, name, val):
             if not isinstance(val, Mapping):
                 raise TypeError("{} Expected a Mapping", name)
             if (
-                    isinstance(field_definition.items, list)
-                    and len(field_definition.items) == 2
+                isinstance(field_definition.items, list)
+                and len(field_definition.items) == 2
             ):
                 key_type, value_type = field_definition.items
                 return {
@@ -367,22 +368,25 @@ def serialize_val(field_definition, name, val):
                 }
         if isinstance(field_definition.items, list):
             return [
-                serialize_val(field_definition.items[ind], name, v)
+                serialize_val(field_definition.items[ind], name, v, mapper=mapper)
                 for ind, v in enumerate(val)
             ]
         elif isinstance(field_definition.items, Field):
-            return [serialize_val(field_definition.items, name, i) for i in val]
+            return [
+                serialize_val(field_definition.items, name, i, mapper=mapper)
+                for i in val
+            ]
         else:
-            return [serialize_val(None, name, i) for i in val]
+            return [serialize_val(None, name, i, mapper=mapper) for i in val]
     if isinstance(val, (list, set, tuple)):
         return [serialize_val(None, name, i) for i in val]
     if isinstance(field_definition, Anything):
         if isinstance(val, Structure):
-            return serialize(val)
+            return serialize(val, mapper=mapper)
         elif isinstance(val, Field):
-            return serialize_val(None, name, val)
+            return serialize_val(None, name, val, mapper=mapper)
     if isinstance(val, Structure) or isinstance(field_definition, Field):
-        return serialize_internal(val)
+        return serialize_internal(val, mapper=mapper)
     # nothing worked. Not a typedpy field. Last ditch effort.
     try:
         return json.loads(json.dumps(val))
@@ -452,10 +456,10 @@ def serialize_internal(structure, mapper=None, compact=False):
     fields = list(field_by_name.keys())
     additional_props = props.get("_additionalProperties", True)
     if (
-            len(fields) == 1
-            and props.get("_required", fields) == fields
-            and additional_props is False
-            and compact
+        len(fields) == 1
+        and props.get("_required", fields) == fields
+        and additional_props is False
+        and compact
     ):
         key = fields[0]
         result = serialize_val(
@@ -476,8 +480,9 @@ def serialize_internal(structure, mapper=None, compact=False):
             the_field_definition = (
                 Anything if mapped_value else field_by_name.get(key, None)
             )
+            sub_mapper = mapper.get(f"{key}._mapper", {})
             result[mapped_key] = serialize_val(
-                the_field_definition, key, mapped_value or val
+                the_field_definition, key, mapped_value or val, mapper=sub_mapper
             )
     return result
 
@@ -521,6 +526,8 @@ def serialize(value, *, mapper: Dict = None, compact=False):
             return serialize_val(field_definition, field_definition._name, value)
         if isinstance(value, (enum.Enum,)):
             return value.name
-        raise TypeError("serialize: Not a Structure or Field that with an obvious serialization. Got: {}."
-                        " Maybe try serialize_field() instead?".format(value))
+        raise TypeError(
+            "serialize: Not a Structure or Field that with an obvious serialization. Got: {}."
+            " Maybe try serialize_field() instead?".format(value)
+        )
     return serialize_internal(value, mapper=mapper, compact=compact)
