@@ -7,11 +7,6 @@ from collections import OrderedDict
 from inspect import Signature, Parameter
 import sys
 
-# support:
-# json schema draft 4,
-# Structure inheritance,
-# fields of class reference
-# embedded structures
 from typing import get_type_hints, Iterable
 
 
@@ -127,7 +122,7 @@ class Field:
         ):
             instance.__validate__()
 
-    def __serialize__(self, value):
+    def __serialize__(self, value):  # pylint: disable=R0201
         return value
 
     def __str__(self):
@@ -172,9 +167,9 @@ def _get_all_fields_by_name(cls):
     all_classes = reversed([c for c in cls.mro() if isinstance(c, StructMeta)])
     all_fields_by_name = {}
     for the_class in all_classes:
-        field_by_name = dict(
-            [(k, v) for k, v in the_class.__dict__.items() if isinstance(v, Field)]
-        )
+        field_by_name = {
+            k: v for k, v in the_class.__dict__.items() if isinstance(v, Field)
+        }
         all_fields_by_name.update(field_by_name)
     return all_fields_by_name
 
@@ -303,7 +298,6 @@ class Structure(metaclass=StructMeta):
             if name in self.__dict__
         }
 
-
     def __str__(self):
         def list_to_str(values):
             as_strings = [to_str(v) for v in values]
